@@ -1,6 +1,7 @@
-# Third-party imports.
 import requests
 
+import disruptive.logging as dtlog
+
 
 class DTApiError(Exception):
     """
@@ -13,6 +14,9 @@ class DTApiError(Exception):
         # Call the base class constructor.
         super().__init__(message)
 
+        # Log the error.
+        dtlog.error(message)
+
 
 class BadRequest(DTApiError):
     """
@@ -132,6 +136,36 @@ class ConfigurationError(DTApiError):
         super().__init__(message)
 
 
+class EmptyStringError(DTApiError):
+    """
+    Unexpected empty string.
+
+    """
+
+    def __init__(self, message):
+        super().__init__(message)
+
+
+class TypeError(DTApiError):
+    """
+    Unexpected type.
+
+    """
+
+    def __init__(self, message):
+        super().__init__(message)
+
+
+class ValueError(DTApiError):
+    """
+    Unexpected value.
+
+    """
+
+    def __init__(self, message):
+        super().__init__(message)
+
+
 class UnknownError(DTApiError):
     """
     An unexpected error has been raised.
