@@ -1,14 +1,11 @@
 from __future__ import annotations
 
-# Standard library imports.
 from typing import Optional
 
-# Project imports.
 import disruptive
 import disruptive.logging as dtlog
 import disruptive.requests as dtrequests
 import disruptive.outputs as dtoutputs
-from disruptive.outputs import Metric
 
 
 class DataConnector(dtoutputs.OutputBase):
@@ -92,8 +89,8 @@ class DataConnector(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -137,8 +134,8 @@ class DataConnector(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -168,7 +165,7 @@ class DataConnector(dtoutputs.OutputBase):
                              config: disruptive.DataConnector.HttpPushConfig,
                              display_name: str = '',
                              status: str = 'ACTIVE',
-                             events: list[str] = [],
+                             event_types: list[str] = [],
                              labels: list[str] = [],
                              **kwargs,
                              ) -> DataConnector:
@@ -185,7 +182,7 @@ class DataConnector(dtoutputs.OutputBase):
             Sets a display name for the project.
         status : {"ACTIVE", "USER_DISABLED"} strm optional
             Status of the new Data Connector.
-        events : list[str], optional
+        event_types : list[str], optional
             List of event types the Data Connector should forward.
         labels : list[str], optional
             List of labels to forward with each event.
@@ -194,8 +191,8 @@ class DataConnector(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -219,7 +216,7 @@ class DataConnector(dtoutputs.OutputBase):
         # Construct request body dictionary.
         body: dict = dict()
         body['status'] = status
-        body['events'] = events
+        body['events'] = event_types
         body['labels'] = labels
         if len(display_name) > 0:
             body['displayName'] = display_name
@@ -247,7 +244,7 @@ class DataConnector(dtoutputs.OutputBase):
         config: Optional[disruptive.DataConnector.HttpPushConfig] = None,
         display_name: Optional[str] = None,
         status: Optional[str] = None,
-        events: Optional[list[str]] = None,
+        event_types: Optional[list[str]] = None,
         labels: Optional[list[str]] = None,
         **kwargs,
     ) -> DataConnector:
@@ -267,7 +264,7 @@ class DataConnector(dtoutputs.OutputBase):
             Sets a display name for the Data Connector.
         status : {"ACTIVE", "USER_DISABLED"} str, optional
             Status of the Data Connector.
-        events : list[str], optional
+        event_types : list[str], optional
             List of event types the Data Connector should forward.
         labels : list[str], optional
             List of labels to forward with each event.
@@ -276,8 +273,8 @@ class DataConnector(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -299,7 +296,7 @@ class DataConnector(dtoutputs.OutputBase):
         ...     project_id='<PROJECT_ID>',
         ...     display_name='new-name',
         ...     labels=['room-number', 'customer-id'],
-        ...     events=[
+        ...     event_types=[
         ...         disruptive.events.TOUCH,
         ...         disruptive.events.TEMPERATURE,
         ...         ],
@@ -313,8 +310,8 @@ class DataConnector(dtoutputs.OutputBase):
             body['displayName'] = display_name
         if status is not None:
             body['status'] = status
-        if events is not None:
-            body['events'] = events
+        if event_types is not None:
+            body['events'] = event_types
         if labels is not None:
             body['labels'] = labels
 
@@ -354,8 +351,8 @@ class DataConnector(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Examples
         --------
@@ -397,8 +394,8 @@ class DataConnector(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -450,8 +447,8 @@ class DataConnector(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Examples
         --------
@@ -492,7 +489,7 @@ class DataConnector(dtoutputs.OutputBase):
             )
         else:
             # If this else statement runs, no config is available for type.
-            dtlog.log('No config available for {} dataconnectors.'.format(
+            dtlog.warning('No config available for {} dataconnectors.'.format(
                 dataconnector_type
             ))
             return None
@@ -547,3 +544,33 @@ class DataConnector(dtoutputs.OutputBase):
             if self.headers is not None:
                 config['headers'] = self.headers
             return 'httpConfig', config
+
+
+class Metric(dtoutputs.OutputBase):
+    """
+    Represents the metrics for a dataconnector over the last 3 hours.
+
+    Attributes
+    ----------
+    success_count : int
+        Number of 2xx responses.
+    error_count : int
+        Number of non-2xx responses.
+    latency : str
+        Average latency.
+
+    """
+
+    def __init__(self, metric: dict) -> None:
+        """
+        Constructs the Metric object by unpacking the raw response.
+
+        """
+
+        # Inherit attributes from ResponseBase parent.
+        dtoutputs.OutputBase.__init__(self, metric)
+
+        # Unpack attributes from dictionary.
+        self.success_count = metric['metrics']['successCount']
+        self.error_count = metric['metrics']['errorCount']
+        self.latency = metric['metrics']['latency99p']
